pyautomail.storage
==================

.. automodule:: pyautomail.storage
   :members:
   :undoc-members:
   :show-inheritance:



pyautomail.storage.model
------------------------


.. automodule:: pyautomail.storage.model
   :members:
   :undoc-members:
   :show-inheritance:

pyautomail.storage.util
-----------------------


.. automodule:: pyautomail.storage.util
   :members:
   :undoc-members:
   :show-inheritance:
